@@ -1,7 +1,6 @@
 # ecoding=utf-8
 
 
-
 def 颜色(text, 色选):
     if 色选 == "粉色":
         return f"\033[0;35;40m{text}\033[0m"
@@ -31,35 +30,14 @@ def 颜色(text, 色选):
         return f'\033[46m{text}6\033[0m'
 
 
-
-
-
-
-
-
-def 日志(text, 色选=None):
+def 日志(text):
     import time
-    if 色选 is not None:
-        text = (str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()) + f":{text}"))
-        textok=颜色(text, 色选)
-        return textok
-    else:
-        return str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()) + f":{text}")
+    return str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())) + str(f":{text}")
 
-
-def 分割线(text, s模式, 颜色a=False):
-    if 颜色a:
-        text = f"\n\n\n\n\n\n- {text} -  {s模式} :\n-------------------------\n"
-        textok = 颜色(text, s模式)
-        return(textok)
-    else:
-        return f"\n\n\n\n\n\n- {text} -  {s模式}:\n--------------------------\n"
-
-
-
-
-
-
-
+def 系统日志(text):
+    import time
+    return 颜色(str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime())),色选="紫色") + str(f":{text}")
 
 
+def 分割线(标题, text):
+    return f"\n\n\n\n\n\n- {标题} -  {text}:\n--------------------------\n"
